==> dome-2.00.tar.bz2: dome-2.00/astrohaven.h <==
#ifndef _Astrohaven_H
#define _Astrohaven_H

#include <string>
#include <queue>
#include <pthread.h>

#include "module.h"
#include "configs.h"
#include "deftypes.h"

class Astrohaven : public Module {
    static const SComm A_OPEN;
    static const SComm A_CLOSE;
    static const SComm A_BACK;
    static const SComm B_OPEN;
    static const SComm B_CLOSE;
    static const SComm B_BACK;
    static const SComm STOP;
    static const SComm UNLOCK;
    static const SComm LOCK;
    static const SWord SET_LIM_TIME;
    static const SWord SET_ACTIVITY;
    static const SWord SET_UNLOCK_DEL;
    static const SByte SET_MAX_CURRENT;
    static const SByte MOVE_A_TO;
    static const SByte MOVE_B_TO;
    static const AByte GET_TILT_A;
    static const AByte GET_TILT_B;
    static const AWord GET_POWER_VOLTAGE;
    static const AWord GET_TEMPERATURE;
    int sleep_time;
    int lim_motion_time;
    double open_release;
    double close_release;
    double max_current;
    unsigned int    A_tilt_open;
    unsigned int    A_tilt_close;
    unsigned int    B_tilt_open;
    unsigned int    B_tilt_close;
    static pthread_t Watch_thread;
private:
    static void* thread( void* );
    void lineWatchdog();
    class Handler {
    public:
        static bool expired;
    private:
        static void catch_stop( int );
        static Astrohaven *curts;
    public:
        Handler( Astrohaven *th );
    };
    bool check_error( const std::string& );
    unsigned int  tilt_A();
    unsigned int  tilt_B();
    void nsleep(double );
public:
    Astrohaven( Config&, RS485&, const std::string& );
    ~Astrohaven();
    void close_a();
    void close_b();
    void open_a();
    void open_b();
    void move_a( double );
    void move_b( double );
    const std::string& devStatus();
    int time();
    bool is_closed( bool A, bool B);
    bool is_opened( bool A, bool B);
    double sideA_position();
    double sideB_position();
};

#endif

==> dome-2.01.tar.bz2: dome-2.01/astrohaven.h <==
#ifndef _Astrohaven_H
#define _Astrohaven_H

#include <string>
#include <queue>
#include <pthread.h>

#include "module.h"
#include "configs.h"
#include "deftypes.h"

class Astrohaven : public Module {
    static const SComm A_OPEN;
    static const SComm A_CLOSE;
    static const SComm A_BACK;
    static const SComm B_OPEN;
    static const SComm B_CLOSE;
    static const SComm B_BACK;
    static const SComm STOP;
    static const SComm UNLOCK;
    static const SComm LOCK;
    static const SWord SET_LIM_TIME;
    static const SWord SET_ACTIVITY;
    static const SWord SET_UNLOCK_DEL;
    static const SByte SET_MAX_CURRENT;
    static const SByte MOVE_A_TO;
    static const SByte MOVE_B_TO;
    static const AByte GET_TILT_A;
    static const AByte GET_TILT_B;
    static const AWord GET_POWER_VOLTAGE;
    static const AWord GET_TEMPERATURE;
    int sleep_time;
    int lim_motion_time;
    double open_release;
    double close_release;
    double max_current;
    int    A_tilt_open;
    int    A_tilt_close;
    int    B_tilt_open;
    int    B_tilt_close;
    static pthread_t Watch_thread;
private:
    static void* thread( void* );
    void lineWatchdog();
    class Handler {
    public:
        static bool expired;
    private:
        static void catch_stop( int );
        static Astrohaven *curts;
    public:
        Handler( Astrohaven *th );
    };
    bool check_error( const std::string& );
    int  tilt_A();
    int  tilt_B();
    void nsleep(double );
public:
    Astrohaven( Config&, RS485&, const std::string& );
    ~Astrohaven();
    void close_a();
    void close_b();
    void open_a();
    void open_b();
    void move_a( double );
    void move_b( double );
    const std::string& devStatus();
    int time();
    bool is_closed( bool A, bool B);
    bool is_opened( bool A, bool B);
    double sideA_position();
    double sideB_position();
};

#endif
